#
# spec file for package sccache
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define configdir %{_sysconfdir}/%{name}

Name:           sccache
Version:        0.2.15~git0.6b6d2f7
Release:        150400.1.49
Summary:        A compiler caching tool for Rust, C and C++ with optional cloud storage
License:        (0BSD OR MIT OR Apache-2.0) AND (Apache-2.0 OR BSL-1.0) AND (Apache-2.0 OR MIT) AND (Apache-2.0 OR Apache-2.0 WITH LLVM-exception OR MIT) AND (Apache-2.0 OR CC0-1.0) AND ((Apache-2.0 AND BSD-2-Clause) OR MIT) AND (Apache-2.0 OR MIT OR BSD-2-Clause) AND (Apache-2.0 OR MIT OR Zlib) AND (Apache-2.0 OR MIT OR Zlib) AND (MIT OR Unlicense) AND (Apache-2.0 OR Zlib OR MIT) AND Apache-2.0 AND BSD-2-Clause AND BSD-3-Clause AND CC0-1.0 AND ISC AND MIT
Group:          Development/Languages/Rust
URL:            https://github.com/mozilla/%{name}
Source0:        %{name}-%{version}.tar.xz
Source1:        vendor.tar.xz
Source2:        cargo_config
Source10:       sccache-dist-builder.service
Source11:       sccache-dist-scheduler.service
Source12:       builder.conf
Source13:       scheduler.conf
Source14:       client.example
BuildRequires:  cargo-packaging
BuildRequires:  pkgconfig(openssl)
Requires:       bubblewrap
ExclusiveArch:  x86_64 i586 i686 armv7hl aarch64

%description
Sccache is a ccache-like tool. It is used as a compiler wrapper and
avoids compilation when possible, storing a cache in a remote storage
using the Amazon Simple Cloud Storage Service (S3) API, Redis or
the Google Cloud Storage (GCS) API.

%prep
%setup -q
%setup -qa1
mkdir .cargo
cp %{SOURCE2} .cargo/config
# Remove exec bits to prevent an issue in fedora shebang checking
find vendor -type f -name \*.rs -exec chmod -x '{}' \;

%build
# 'dist-server' available only on x86_64 so far - https://github.com/mozilla/sccache/issues/656
features="all,dist-client"
%ifarch x86_64
features="$features,dist-server"
%endif
%{cargo_build} --features=$features

%install
install -D -d -m 0755 %{buildroot}%{_bindir}
install -D -d -m 0755 %{buildroot}%{_unitdir}
install -D -d -m 0755 %{buildroot}%{configdir}

install -m 0755 %{_builddir}/%{name}-%{version}/target/release/sccache %{buildroot}%{_bindir}/sccache
%ifarch x86_64
install -m 0755 %{_builddir}/%{name}-%{version}/target/release/sccache-dist %{buildroot}%{_bindir}/sccache-dist
%endif

%ifarch x86_64
install -m 0644 %{SOURCE10} %{buildroot}%{_unitdir}/sccache-dist-builder.service
install -m 0644 %{SOURCE11} %{buildroot}%{_unitdir}/sccache-dist-scheduler.service
%endif
install -m 0644 %{SOURCE12} %{buildroot}%{configdir}/builder.conf
install -m 0644 %{SOURCE13} %{buildroot}%{configdir}/scheduler.conf
install -m 0644 %{SOURCE14} %{buildroot}%{configdir}/client.example

%ifarch x86_64
%pre
%service_add_pre sccache-dist-builder.service
%service_add_pre sccache-dist-scheduler.service

%post
%service_add_post sccache-dist-builder.service
%service_add_post sccache-dist-scheduler.service

%preun
%service_del_preun sccache-dist-builder.service
%service_del_preun sccache-dist-scheduler.service

%postun
%service_del_postun sccache-dist-builder.service
%service_del_postun sccache-dist-scheduler.service
%endif

%files
%license LICENSE
%doc README.md
%{_bindir}/sccache
%ifarch x86_64
%{_bindir}/sccache-dist

%{_unitdir}/sccache-dist-builder.service
%{_unitdir}/sccache-dist-scheduler.service
%endif

%dir %{configdir}
%config(noreplace) %{configdir}/scheduler.conf
%config(noreplace) %{configdir}/builder.conf
%config(noreplace) %{configdir}/client.example

%changelog
* Wed Nov  3 2021 william.brown@suse.com
- relates jsc#SLE-22290 improve rust developer tooling
- Update license string in rpm
- Update vendor libraries
* Thu Oct 21 2021 william.brown@suse.com
- Extend supported arches for potential OBS usage
* Mon Oct 11 2021 wbrown@suse.de
- Set _service to use automatic vendor updates
- Set exclusive arches to match tier 1
* Tue Sep 28 2021 william.brown@suse.com
- Change from rust-packaging to cargo-packaging
* Mon Jul  5 2021 william.brown@suse.com
- Update vendored dependencies to resolve
  - - potential memory corruption ( RUSTSEC-2021-0003 )
  - - potential format injection ( RUSTSEC-2021-0020 )
  - - potential request smuggling ( RUSTSEC-2020-0031 )
* Tue Jun 22 2021 william.brown@suse.com
- Allow extra architectures with sccache
* Wed Jan 13 2021 wbrown@suse.de
- Update to version 0.2.15~git1.22a176c:
  * (cargo-release) start next development iteration 0.2.16-alpha.0
  * (cargo-release) version 0.2.15
  * Update docs/Releasing.md
  * Workaround tiny_http issue #151 by disabling HTTP pipelining
  * Upgrade itertools to 0.10
  * Run `cargo update`
  * Add C compiler versions to the hash calculation when available
  * Move lru-disk-cache to an internal module
  * Fix clippy warnings in lru-disk-cache
  * Still read config file from Library/Preferences if it exists
* Tue Dec 22 2020 wbrown@suse.de
- Update to version 0.2.14~git0.655ef1a:
  * (cargo-release) version 0.2.14
  * Remove [patch] section for the purpose of release
  * Upgrade zstd to 0.6
  * Run `cargo update`
  * Bump lru-disk-cache version
  * Fix a few more clippy warnings
  * Make lru_disk_cache::Error's impl Display match what it was before 65bb3b6
  * Ignore both -FS and -MP on MSVC
  * Use a full path relative to `cwd` for extra hash files
  * Set the current directory of the server to the directory containing the executable
* Wed Nov 25 2020 guillaume.gardet@opensuse.org
- Fix build on non-x86_64 archs
* Fri Nov 20 2020 william.brown@suse.com
- Fix service file commit definition
- Correct spec file example install
* Thu Nov 19 2020 wbrown@suse.de
- Update to version 0.2.13~git474.6628e1f:
  * New entry in ServerStartup enum to indicate AddrInUse Error (#840)
  * Revert "Bump to tiny-http 0.7.0 (#830)" because it caused a regression, #846.
  * Include -fsanitizer-blacklist in common_args
  * Consume sanitizer blacklist as extra hash in msvc (#842)
  * In case we fail to read the compressed content from the cache, treat the failure as a forced
    recache. This prevents us from failing build jobs unconditionally if cache entries are corrupt
    (or in case of other sporadic failures), in which case we should continue on with
    force-recompiling and recaching. (#836)
  * Bump to tiny-http 0.7.0 (#830)
  * Modify logging to use SCCACHE_LOG. (#822)
  * Implement `g++` and `clang++` behavior when used on a `.c` input file. Fixes #803 (#818)
  * clang: Allow chrome plugin arguments (#817)
  * Add known caveats section to readme (#815)
* Wed Nov 18 2020 william.brown@suse.com
- Configure features to generate sccache-dist for distributed builds.
- Add systemd unit files for builder and scheduler and example configs.
* Wed Nov 18 2020 william.brown@suse.com
- Add --features=all to allow all cache backends to be used.
* Tue Nov 17 2020 william.brown@suse.com
- Add support for obs cargo vendor to make packaging easier.
  * osc service ra - now can update the source files.
- Improvements to spec file.
- Fix invalid license string.
* Fri May 22 2020 sjamgade@suse.com
- Initial Package
